#
# spec file for package trinity
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 1.6+git.20160603

Name:           trinity
Version:        1.6+git.20160603
Release:        1.1
Summary:        A Linux System call fuzz tester
License:        GPL-2.0
Group:          Development/Tools/Other
Url:            http://codemonkey.org.uk/projects/trinity/
Source0:        %{name}-%{version}.tar.xz
# SLE11-SP*, for -std=gnu11
%if 0%{suse_version} == 1110

%if 0%{?product_libs_gcc_ver} == 48
#SP4
%define gcc_minor 8
%else
#SP3
%define gcc_minor 7
%endif

BuildRequires:  gcc4%{gcc_minor}
%else
BuildRequires:  gcc
%endif

%if 0%{suse_version} >= 1320
# needed for btrfs/ioctl.h
BuildRequires:  libbtrfs-devel
%endif
%if 0%{suse_version} >= 1330
# builds for 32 bit architectures are failing on Tumbleweed
ExcludeArch:    %ix86 %arm
%endif
BuildRequires:  make
BuildRequires:  xz

# older packages which use old versioning scheme need to be obsoleted,
# this can be removed in the future
Provides:       %{name} = 20160315
Obsoletes:      %{name} = 20160315
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The basic idea is fairly simple. As 'fuzz testing' suggests, we call syscalls
at random, with random arguments.  Not an original idea, and one that has been
done many times before on Linux, and on other operating systems.  Where
Trinity differs is that the arguments it passes are not purely random.

%prep
%setup -q

%build
%if 0%{suse_version} == 1110
export CC=gcc-4.%{gcc_minor}
%endif
export CFLAGS="%{optflags}"
./configure
make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot}/usr install
install -D -m 0644 trinity.1 %{buildroot}%{_mandir}/man1/trinity.1

%files
%defattr(-,root,root)
%doc README COPYING
%{_bindir}/trinity
%{_mandir}/man1/trinity.1%{ext_man}

%changelog
* Sun Jun 12 2016 mpluskal@suse.com
- Update to version 1.6+git.20160603:
  * if we use the fallback seed, don't use rand() yet.
  * Before falling back to gtod, try getrandom() if available.
- Change _service to disabled
* Fri May 27 2016 mpluskal@suse.com
- Update to version 1.6+git.20160526:
  * for each random syscall, do one in an extra child too.
  * compile fix.
  * fix memory leak on child fork failure.
  * check for potential failure to acquire testfile fd.
  * fds/drm.c: Add forward declaration of struct.
  * flesh out the bpf sanitiser a little.
  * introduce object types for bpf maps & progs
  * make the BPF_PROG_LOAD case look more sane
  * bpf: only do bpf_gen_filter for BPF_PROG_TYPE_SOCKET_FILTER
  * fix wrong variable name in childops wait
* Sat May 21 2016 mpluskal@suse.com
- Update to version 1.6+git.20160520:
  * split num_fd_providers_enabled into two vars.
  * make setup_fd_providers silent, so it doesn't spew during -h
  * add flags from 4.7 for preadv2/pwritev2
  * if random_ipv4_address picked localhost last time, let it happen again.
  * Convert fd provider initialization to use constructors
  * include file cleanup
  * document how register_fd_provider gets run
  * merge enable_fds_param/disable_fds_param into toggle_fds_param
  * shut up clang
  * fix up more clang detritus
  * change set_dontkillme to take a child struct instead of a pid
  * bump the child progress indicator in set_dontkillme
* Sun May 15 2016 mpluskal@suse.com
- Update to version 1.6+git.20160513:
  * don't call fcntl on -1 fd's
  * only do the 'stuck syscall' info on children running random syscalls
  * print the error if the initial mmaps fail
  * fix offset for 1GB pages.
  * when disabling 1GB pages, just do nothing
* Wed Apr 27 2016 mpluskal@suse.com
- Update to version 1.6+git.20160426:
  * fix the 'pick new childop' code.
  * remove the shm_rw debug code.
  * store the type of childop we're doing in the child struct
  * remove the 10MB initial mapping.
  * be careful not to read past the end of the ip_ssoptrs array
  * define maximum size of ip_ssoptrs array
  * push the dropprivs code down into the child processes.
  * bump the 'pick new op' counter even higher.
  * add a 'read /proc/<pid>/status' childop
  * fix leaks in thrash-pid-files
  * reformat childop structs
  * convert uid.c to use output() instead of outputerr()
  * set a flag in the child struct when we've dropped privs
  * factor out the 'set new op' code to a separate function
  * rewrite set_new_op to take ptrs to alternative childops.
  * Introduce 'root child ops'.
* Fri Apr 22 2016 mpluskal@suse.com
- Update to version 1.6+git.20160422:
  * update the prototypes for the read-all-files childop
  * children/ -> childops/
  * move op_nr from syscall record to childdata
  * fix open() return code check
  * open/stat instead of stat/open
  * use fstat instead of lstat
  * reset the op ptr when we reach the loop counter.
  * reset the child timestamp when we clean it out
  * Add new CLONE_NEWCGROUP flag
  * change stats to count operations, not just syscalls
* Wed Apr 20 2016 mpluskal@suse.com
- Update to version 1.6+git.20160420:
  * reset the op ptr when we reach the loop counter.
  * reset the child timestamp when we clean it out
  * Add new CLONE_NEWCGROUP flag
* Sat Apr 16 2016 mpluskal@suse.com
- Update to version 1.6+git.20160416:
  * move the "child progressing" timestamp from the syscall rec to the child.
  * change reap_child to take child struct
  * pass the child ptr down to the child op.
  * fix badly named child_random_syscalls()
  * repeat the previous childop 1000 times
  * update the prototypes for the read-all-files childop
  * children/ -> childops/
  * move op_nr from syscall record to childdata
  * fix open() return code check
  * open/stat instead of stat/open
* Tue Apr 12 2016 mpluskal@suse.com
- Update to version 1.6+git.20160408:
  * add a ->send method to struct netproto
  * add pwritev2/preadv2
  * add SO_CNX_ADVICE setsockopt
  * add MSG_BATCH flag
  * if a proto's ->send is missing, fallback to random
  * decode netlink protocols
  * add missing NETLINK_ROUTE decoding
  * when per proto ->socket succeeds, indicate success so we don't fall back
  * Only pick a single netlink group
  * rename ->send to ->gen_packet, and redefine args.
* Sat Apr  2 2016 mpluskal@suse.com
- Update to version 1.6~git.20160331:
  + add ext[234] ioctls
  + remove unnecessary include
  + add bare-bones PF_KCM support
  + use SOCK_RAW for IP sockets half the time.
  + make get_new_random_fd bail early if no fd provider has finished yet.
  + by default, start nr_cpus * 4 child processes.
  + EBADF is a possible return from execve
  + remove some noise from potential failures from unshare()
  + add l2tp to analyze-sockets
  + add a ->send method to struct netproto
- Change versioning scheme
  + do not use just date
  + add corresponding obsoletes/provides for smooth transition
- Update _service
  + exclude .git when generating tarball
  + enable automatic changelog updating
- Update dependencies
  * add libbtrfs-devel as it provides btrfs/ioctl.h
* Sun Mar 20 2016 mpluskal@suse.com
- Update to 20160315
- Install manpage
* Wed Mar  2 2016 normand@linux.vnet.ibm.com
- Update to 20160301 to avoid PowerPC build failure
  remove 0001-net-protocols.c-fix-build-on-old-machines.patch
* Tue Feb  2 2016 jslaby@suse.com
- Update to 20160131
- remove 0001-compat.h-add-more-macros.patch (upstream)
- remove 0002-Makefile-fix-build-with-older-glibc.patch (upstream)
- add 0001-net-protocols.c-fix-build-on-old-machines.patch
* Mon Jan  4 2016 jslaby@suse.com
- Update to 20151230
- add 0001-compat.h-add-more-macros.patch
- add 0002-Makefile-fix-build-with-older-glibc.patch
* Mon Dec 21 2015 mpluskal@suse.com
- Update to 20151221
* Mon Dec 14 2015 mpluskal@suse.com
- Update to 20151214
* Sat Dec  5 2015 mpluskal@suse.com
- Update to 20151204
- Make building more verbose
- Use default optflags for building
* Mon Nov  2 2015 jslaby@suse.com
- Update to 20151029
* Thu Sep 17 2015 mpluskal@suse.com
- Update to 20150905
* Wed Aug 19 2015 mpluskal@suse.com
- Update to 20150804
- Drop older-distros.patch it is already part of upstream
* Tue Jun 30 2015 jslaby@suse.com
- Update to 20150629
- Add older-distros.patch: support for SLE11
* Mon Jun 22 2015 mpluskal@suse.com
- Update to 20150617
* Thu Apr 30 2015 jslaby@suse.com
- Update to 20150429
* Tue Feb 17 2015 mpluskal@suse.com
- Update to 20150215
* Wed Jan 14 2015 jslaby@suse.com
- update to 20150107
* Sat Dec 13 2014 mpluskal@suse.com
- Update to 20141206
* Sat Nov 22 2014 mpluskal@suse.com
- Update to 20141117
* Tue Nov 11 2014 mpluskal@suse.com
- Add COPYING with license
- Update to 20141110
* Wed Oct 22 2014 mpluskal@suse.com
- Update to 20141022
  * modify_ldt-initialize-scratch.patch: removed
- Change git source to github
* Mon Jan 20 2014 jslaby@suse.com
- update to 20140119
  * compat-define-some-net-constants.patch: removed
  * fix-broken-includes.patch: removed
  * net-netlink-add-missing-compat.h-include.patch: removed
  * perf-fixes.patch: removed
- add modify_ldt-initialize-scratch.patch
* Sun Sep 15 2013 jslaby@suse.com
- update to 20130913
  * perf-fixes.patch: removed
  * seccomp.patch : removed
  * PR_MCE_KILL_GET.patch: removed
  * compat-define-some-net-constants.patch: added
  * net-netlink-add-missing-compat.h-include.patch: added
  * fix-broken-includes.patch: added
* Tue Jun  4 2013 jslaby@suse.com
- update to 20130603
  * PR_MCE_KILL_GET.patch: added
  * perf-fixes.patch: added
  * seccomp.patch: added
  * compat-define-MS_BORN-constant.patch: removed
  * compat-define-some-KVM_-constants.patch: removed
  * fix-stupid-header-requirements.patch: removed
  * fix-tpacket3_hdr-build-failure.patch: removed
* Mon May 20 2013 jslaby@suse.com
- update to 20130517
- setsockopt-remove-some-more-opts.patch: removed
- fix-stupid-header-requirements.patch: added
- fix-tpacket3_hdr-build-failure.patch: added
- compat-define-MS_BORN-constant.patch: added
- compat-define-some-KVM_-constants.patch: added
* Fri Mar  1 2013 jslaby@suse.com
- update to 20130227
  - remove most of patches, they are upstream -- hooray
- compat.h-add-KEYCTL.patch: removed
- compat.h-add-some-more-constants.patch: removed
- handle-missing-rds.patch: removed
- sockaddr-remove-L2TPv3.patch: removed
- sockaddr-remove-PF_CAIF-PF_ALG.patch: removed
- sockaddr-remove-PF_NFC.patch: removed
- sockaddr-remove-PF_PROTO_PPTP.patch: removed
* Tue Feb 26 2013 jslaby@suse.com
- update to 20130223
  * added more tests
  * many cleanups
- compat.h-add-KEYCTL.patch: added
- 0001-compat.h-add-SO_BSDCOMPAT.patch: removed
- 0002-compat.h-add-RLIMIT_RTTIME.patch: removed
- 0003-compat.h-add-newer-net-constants.patch: removed
* Fri Jan 11 2013 jslaby@suse.com
- make some patches more robust (use compat.h)
  * they'll go to upstream
* Thu Jan 10 2013 jslaby@suse.com
- update to 20130109
  * added more tests
  * many cleanups
* Fri Nov 30 2012 jslaby@suse.com
- update to 20121129
  * added more tests
  * many cleanups
- syscalls-remove-RLIMIT_RTTIME.patch added to fix another build
  failures on <= 1200
* Mon Oct 29 2012 jslaby@suse.com
- initial package
